==> hal-testsuite-common-0.0.3-sources.jar: org/jboss/hal/testsuite/finder/FinderNames.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.hal.testsuite.finder;

/**
 * @author Harald Pehl
 */
public interface FinderNames {

    String ADD = "Add";
    String BROWSE_BY = "Browse By";
    String BROWSE_DOMAIN_BY = "Browse Domain By";
    String CONFIGURATION = "Configuration";
    String DEPLOYMENT = "Deployment";
    String HOST = "Host";
    String HOSTS = "Hosts";
    String LOG_FILES = "Log Files";
    String MONITOR = "Monitor";
    String PROFILE = "Profile";
    String PROFILES = "Profiles";
    String REMOVE = "Remove";
    String SERVER = "Server";
    String SERVER_GROUP = "Server Group";
    String SERVER_GROUPS = "Server Groups";
    String STANDALONE_SERVER = "Standalone Server";
    String SUBSYSTEM = "Subsystem";
    String SUBSYSTEMS = "Subsystems";
    String VIEW = "View";
}

==> hal-testsuite-common-0.0.5-sources.jar: org/jboss/hal/testsuite/finder/FinderNames.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.hal.testsuite.finder;

/**
 * @author Harald Pehl
 */
public interface FinderNames {

    String ADD = "Add";
    String BROWSE_BY = "Browse By";
    String BROWSE_DOMAIN_BY = "Browse Domain By";
    String CONFIGURATION = "Configuration";
    String DEPLOYMENT = "Deployment";
    String HOST = "Host";
    String HOSTS = "Hosts";
    String LOG_FILES = "Log Files";
    String MONITOR = "Monitor";
    String PROFILE = "Profile";
    String PROFILES = "Profiles";
    String REMOVE = "Remove";
    String REPLACE = "Replace";
    String SERVER = "Server";
    String SERVER_GROUP = "Server Group";
    String SERVER_GROUPS = "Server Groups";
    String STANDALONE_SERVER = "Standalone Server";
    String SUBSYSTEM = "Subsystem";
    String SUBSYSTEMS = "Subsystems";
    String VIEW = "View";

    String DISABLE = "Disable";
    String ENABLE = "Enable";
    String EXPLODE = "Explode";
    String BROWSE_CONTENT = "Browse Content";
}
